#!/usr/bin/env node

'use strict';

// bitbucket-pipeline-slack-notifier
const request = require("request");

const env = process.env;
let repo = `${env.BITBUCKET_REPO_SLUG}`;
let pipelineUrl = `${env.BITBUCKET_GIT_HTTP_ORIGIN}/addon/pipelines/home#!/results/${env.BITBUCKET_BUILD_NUMBER}`;
let commitUrl = `${env.BITBUCKET_GIT_HTTP_ORIGIN}/commits/${env.BITBUCKET_COMMIT}`;

// Parse arguments
let args = process.argv.slice(2);
let messageIndex = args.indexOf('-message');
let teamIndex = args.indexOf('-team');
let channelIndex = args.indexOf('-channel');
let iconIndex = args.indexOf('-icon');
let webhookIndex = args.indexOf('-webhook');

// Validate
if (messageIndex === -1) { return global.console.error('missing parameter -message'); }
if (channelIndex === -1) { return global.console.error('missing parameter -channel'); }
if (webhookIndex === -1 && !env.webhook) { return global.console.error('missing parameter -webhook'); }

// Parse input
let message = `${args[messageIndex + 1]}\n Pipeline: <${pipelineUrl}>`;
let channel = args[channelIndex + 1];
let team = args[teamIndex + 1];
let icon = iconIndex !== -1 ? args[iconIndex + 1] : ':package:';
let webhook = args[webhookIndex + 1] || env.webhook;

// Construct slackMessage
let slackMessage = {
  "attachments": [
    {
      "fallback": message,
      "text": message,
      "pretext": repo,
      "color": "#7CD197",
    }
  ],
  "channel": channel,
  "username": team,
  "icon_emoji": icon,
}

const sendToSlack = async (slackMessage, webhook) => {
  try {
    await request.post({
      url: webhook,
      body: slackMessage,
      json: true,
    });
    global.console.log('Notification sent to slack!');

  } catch (ex) {
    global.console.error('Could not send slack notification!');
    process.exit(1);
  }

}

sendToSlack(slackMessage, webhook);
